@@ -7,6 +7,6 @@ pub fn detect() -> bool {
     Path::new(CONTAINER_ENV).exists()
 }
 
-pub fn run(_args: &[String]) -> Result<(), CnfError> {
+pub fn run(_args: &[&str]) -> Result<(), CnfError> {
     Err(CnfError::NotImplemented("Environment Container".into()))
 }
